@@ -4,6 +4,7 @@ Email::Store::Entity->table("entity");
 Email::Store::Entity->columns(Primary => qw/id/);
 Email::Store::Entity->columns(All => qw/id notes/); # notes is a hack.
 use Email::Address; 
+use Email::MIME;
 use Module::Pluggable::Ordered 
     search_path => ["Email::Store::Entity::Correlator"];
 Email::Store::Entity->set_sql(distinct_entity => q{
@@ -13,9 +14,10 @@ Email::Store::Entity->set_sql(distinct_entity => q{
 sub on_store_order { 1 }
 sub on_store {
     my ($self, $mail) = @_;
-    my $simple = $mail->simple;
+    # This will MIME-decode the headers
+    my $mime = Email::MIME->new($mail->message);
     for my $role (qw(To From Cc Bcc)) {
-        my @addrs = Email::Address->parse($simple->header($role));
+        my @addrs = Email::Address->parse($mime->header($role));
         for my $addr (@addrs) { 
             my $name = Email::Store::Entity::Name->find_or_create({
                 name => ($addr->name || " ")
